@@ -1,14 +1,12 @@
 package App::Wallflower;
-{
-  $App::Wallflower::VERSION = '1.004';
-}
-
+$App::Wallflower::VERSION = '1.005';
 use strict;
 use warnings;
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Pod::Usage;
 use Plack::Util ();
+use URI;
 use Wallflower;
 use Wallflower::Util qw( links_from );
 
@@ -35,6 +33,7 @@ sub new_with_options {
         'follow!',       'filter|files|F',
         'quiet',         'include|INC=s@',
         'host=s@',
+        'url|uri=s',
         'help',          'manual',
         'tutorial',
     ) or pod2usage(
@@ -65,6 +64,10 @@ sub new_with_options {
         -message => 'Missing required option: application'
     ) if !exists $option{application};
 
+    # add the hostname passed via --url to the list built with --host
+    push @{ $option{host} }, URI->new( $option{url} )->host
+       if $option{url};
+
     # include option
     my $path_sep = $Config::Config{path_sep} || ';';
     $option{inc} = [ split /\Q$path_sep\E/, join $path_sep,
@@ -80,6 +83,7 @@ sub new_with_options {
             application => Plack::Util::load_psgi( $option{application} ),
             ( destination => $option{destination} )x!! $option{destination},
             ( index       => $option{index}       )x!! $option{index},
+            ( url         => $option{url}         )x!! $option{url},
         ),
     }, $class;
 
@@ -167,7 +171,7 @@ App::Wallflower - Class performing the moves for the wallflower program
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -202,7 +206,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Philippe Bruhat (BooK).
+This software is copyright (c) 2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
