@@ -1,8 +1,5 @@
 package Wallflower;
-{
-  $Wallflower::VERSION = '1.004';
-}
-
+$Wallflower::VERSION = '1.005';
 use strict;
 use warnings;
 
@@ -13,7 +10,7 @@ use HTTP::Date qw( time2str );
 use Carp;
 
 # quick getters
-for my $attr (qw( application destination env index )) {
+for my $attr (qw( application destination env index url )) {
     no strict 'refs';
     *$attr = sub { $_[0]{$attr} };
 }
@@ -25,6 +22,7 @@ sub new {
         destination => Path::Class::Dir->new(),    # File::Spec->curdir
         env         => {},
         index       => 'index.html',
+        url         => 'http://localhost/',
         %args,
     }, $class;
 
@@ -33,6 +31,18 @@ sub new {
     croak "destination is invalid"
         if !-e $self->destination || !-d $self->destination;
 
+    # turn the url attribute into a URI object
+    $self->{url} = URI->new( $self->url );
+
+    # if the application is mounted somewhere
+    my $path;
+    if ( $path = $self->url->path and $path ne '/' ) {
+        require Plack::App::URLMap;
+        my $urlmap = Plack::App::URLMap->new;
+        $urlmap->mount( $path => $self->application );
+        $self->{application} = $urlmap->to_app;
+    }
+
     return $self;
 }
 
@@ -71,17 +81,18 @@ sub get {
 
         # current instance defaults
         %{ $self->env },
+        ('psgi.url_scheme' => $self->url->scheme )x!! $self->url->scheme,
 
         # request-related environment variables
         REQUEST_METHOD => 'GET',
 
-        # TODO properly deal with SCRIPT_NAME and PATH_INFO with mounts
+        # request attributes
         SCRIPT_NAME     => '',
         PATH_INFO       => $uri->path,
         REQUEST_URI     => $uri->path,
         QUERY_STRING    => '',
-        SERVER_NAME     => 'localhost',
-        SERVER_PORT     => '80',
+        SERVER_NAME     => $self->url->host,
+        SERVER_PORT     => $self->url->port,
         SERVER_PROTOCOL => "HTTP/1.0",
 
         # wallflower defaults
@@ -93,7 +104,7 @@ sub get {
     $env->{HTTP_IF_MODIFIED_SINCE} = time2str( ( stat _ )[9] ) if -e $target;
 
     # fixup URI (needed to resolve relative URLs in retrieved documents)
-    $uri->scheme('http') if !$uri->scheme;
+    $uri->scheme( $env->{'psgi.url_scheme'} ) if !$uri->scheme;
     $uri->host( $env->{SERVER_NAME} ) if !$uri->host;
 
     # get the content
@@ -158,7 +169,7 @@ Wallflower - Stick Plack applications to the wallpaper
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -208,6 +219,13 @@ Additional environment key/value pairs.
 The default filename for URLs ending in C</>.
 The default value is F<index.html>.
 
+=item C<url>
+
+URL where the root of the application will be reachable in production.
+
+If the URL has a path component, the application will be "mounted" at
+that position.
+
 =back
 
 =head2 get( $url )
@@ -256,7 +274,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Philippe Bruhat (BooK).
+This software is copyright (c) 2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
