@@ -1,8 +1,5 @@
 package Wallflower::Util;
-{
-  $Wallflower::Util::VERSION = '1.004';
-}
-
+$Wallflower::Util::VERSION = '1.005';
 use strict;
 use warnings;
 
@@ -57,7 +54,8 @@ sub _links_from_css {
     my ( $file, $url ) = @_;
 
     my $content = do { local ( @ARGV, $/ ) = ("$file"); <> };
-    return grep defined, $content =~ /$css_regexp/gc;
+    return map URI->new_abs( $_, $url ), grep defined,
+        $content =~ /$css_regexp/gc;
 }
 
 1;
@@ -75,7 +73,7 @@ Wallflower::Util - Utility functions for Wallflower
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -110,7 +108,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Philippe Bruhat (BooK).
+This software is copyright (c) 2015 by Philippe Bruhat (BooK).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
